# Converts all image files in folder to a single RAW image data file (in 32-bit
# format ARGB8888) that can be used as input for textures.
# If 'repeat'>1, the image sequence is repeated 'repeat' times (i.e. if folder
# contains 10 pix, repeat=10 means that the RAW file has a total of 100 frames)

from os import listdir
from sdl2 import *
from sdl2.sdlimage import IMG_Load as SDL_LoadImage

########################################
# CONFIG
########################################
image_folder = 'fotos_1366'
raw_file = 'test_1366_32bit_100.raw'
repeat = 10

########################################
# START
########################################

# create RAW file and open it for writing
rw = SDL_RWFromFile(raw_file.encode(), b'wb')

files = listdir(image_folder)
for i in range(repeat):
	for f in files:

		# load image file
		img = SDL_LoadImage((image_folder+'/'+f).encode())

		# convert image to 32-bit (SDL_PIXELFORMAT_ARGB8888)
		img32 = SDL_ConvertSurfaceFormat(img, SDL_PIXELFORMAT_ARGB8888, 0)
		SDL_FreeSurface(img)

		# write image data into RAW file
		data_size = img32.contents.w * img.contents.h * 4
		res = SDL_RWwrite(rw.contents, img32.contents.pixels, data_size, 1)
		if res<0:
			print(SDL_GetError().decode())

		SDL_FreeSurface(img32)

# close the RAW file
SDL_RWclose(rw.contents)

print('Done.')
